function [TbMSG, Temps, Longitudes, Latitudes] = MSGread(ncfilesset, fullfilename)

%MSGread lit le fichier NetCDF MSG du jour souhaite pour en sortir les
%variables (temps, longitudes et latitudes) ainsi que les donnees de
%temperatures de brillance.

%
%+
%
% =========
% MSGread.m
% =========
%
% .. function:: MSGread(fullfilename)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * ncfilesset (en caracteres) : Type de fichier NetCDF que l'on cherche,
%     'normal' ou 'extracted'.
%   * fullfilename : Chemin d'acces au fichier pour la date desiree.
%
% - Donnees de sorties :
%
%   * Temps : Variable de temps du fichier NetCDF.
%   * Longitudes : Variable de longitudes.
%   * Latitudes : Variable de latitudes.
%   * TbMSG : Donnees brutes des temperatures de brillance  dont les
%     dimensions sont respectivement, temps, longitudes et latitudes.
%
% lecture du fichier NetCDF MSG du jour souhaite pour en sortir les
% variables (temps, longitudes et latitudes) ainsi que les donnees de
% temperatures de brillance.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :ref:`varamma_startup.m`
%
% :func:`simul_msg`
% :func:`MSGbuildfullfilename`
%
% :func:`extractedmatrixdata`
% :func:`intensityMSG_day`
% :func:`compar_tbnoyau_disp`
% :func:`compar_tbnoyau_image`
% :func:`compar_tbseuil_histo`
% :func:`compar_tbseuil_image`
% :func:`evolution_msg`
% :func:`histo_intensityMSG`
% :func:`plot_intensityMSG`
% :func:`plotimageMSG`
%
% TODO
% ====
%
% domaine restriction yet on mac and linux (anyway may be not in this module)
%
% handling of missing values
%
% check unit of Temps "HOURS since 1960-01-01 00:00:00" ; in netcdf
%
% homegenize with datajul_value, datestr_value
%
% comprend pourquoi jason a ecrit:
%    Attention! Comme
%    pour EPSAT, ncdump nous donne temps, longitudes, latitudes comme
%    dimensions pour la matrice de donnees qui s'avere etre de dimensions
%    longitudes, latitudes, temps).
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110803T151317Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * display fullfilename
%   * add demo for normal file
%   * move permutation location changed by jaclod (why ?)
%
% - jaclod 2011-07-26
%
%   * Revision de la documentation et des commentaires.
%
% - jaclod 2011-07-21
%
%   * Lecture des fichiers 'extracted' sur Matlab Cratos (Attention! Comme
%     pour EPSAT, ncdump nous donne temps, longitudes, latitudes comme
%     dimensions pour la matrice de donnees qui s'avere etre de dimensions
%     longitudes, latitudes, temps).
%
% - jaclod 2011-07-13
%
%   * Changement des arguments d'entrees 'Annee', 'Mois', 'Jour' par
%     'fullfilename'. Celui-ci peut-etre cree par 'MSGbuildfullfilename'.
%   * Externalisation de la selection de donnees (voir la fonction
%     'extractedmatrixdata').
%
% - pinsard 2011-05-03T08:01:54Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * replace VARAMMA by PROJECT
%
% - fplod 20110309T111842Z loholt1
%
%   * replace ispc() criteria by test on netcdf_open_available to choose
%     netcdf instruction set
%   * permute array after reading 3D data if netcdf.getVar was used
%   * no more hardcoded scale_factor and add_offset
%   * close netcdf opened file
%   * TbMSG int -> double
%
% - fplod 20110304T110110Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * minimal modif to be used on zeus with matlab R2007a :
%     path of dataset, netcdf reading tools
%
%     ok also on octave 3.2.4 on cratos (no netcdf on zeus !!)
%
% - fplod 20110304T082845Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix rst header
%
% - jaclod 2011-03-02
%
%   * Ajout de la documentation et de la demonstration.
%
% - jaclod 2011-02-25
%
%   * Creation.
%
%-

% Appel de la variable global 'netcdf_open_available'.
global netcdf_open_available

% Ouverture du fichier selon l'installation.
if netcdf_open_available
   ncid = netcdf.open(fullfilename, 'NC_NOWRITE');
else
   ncid = netcdf(fullfilename, 'nowrite');
end
disp(['iii : opening for reading ', fullfilename]);

clear fullfilename

% Recuperation des variables selon l'installation et le type de fichier.
if netcdf_open_available

    switch ncfilesset

        case 'normal'

            Temps = netcdf.getVar(ncid,3);
            Longitudes = netcdf.getVar(ncid,1);
            Latitudes = netcdf.getVar(ncid,2);

        case 'extracted'

            % Dans ce cas, longitudes et latitudes sont inverses.
            Temps = netcdf.getVar(ncid,3);
            Longitudes = netcdf.getVar(ncid,2);
            Latitudes = netcdf.getVar(ncid,1);

        otherwise

            error('La variable ncfilesset doit etre ''normal'' ou ''extracted''.');

    end

else

   Temps = ncid{'TIME'}(:);
   Latitudes = ncid{'LATITUDE'}(:);
   Longitudes = ncid{'LONGITUDE'}(:);

end

% Recuperation des donnees de temperature de brillance selon
% l'installation.
if netcdf_open_available

    TbMSG = netcdf.getVar(ncid,0);

    % Application du facteur d'echelle et de la constante a ajouter.
    TbMSG = double(TbMSG) * netcdf.getAtt(ncid,0,'scale_factor') + netcdf.getAtt(ncid,0,'add_offset');

else

   data=ncid{'DATA'}(:,:,:);

   % Application du facteur d'echelle et de la constante a ajouter.
   TbMSG=ncid{'DATA'}.scale_factor(:)*data+ncid{'DATA'}.add_offset(:);
   % demo 1 - normal - octave 3.4 cratos 96x928x1856
   % demo 2 - extracted - octave 3.4 cratos 96x742x742
   % demo 1 - normal - matlab 7.4 cratos 96x928x1856
   % demo 2 - extracted - matlab 7.4 cratos 96x742x742
   % permute to output array with 
   % dimension 1 : temps, dimension 2 : lat,  dimension 3 : lon 
   TbMSG = permute(TbMSG,[1 3 2]);
   % demo 1 - normal - octave 3.4 cratos 96x1856x928
   % demo 2 - extracted - octave 3.4 cratos 96x742x742
   % demo 1 - normal - matlab 7.4 cratos 96x1856x928
   % demo 2 - extracted - matlab 7.4 cratos 96x742x742

end

% Fermeture de la lecture.
if netcdf_open_available

   netcdf.close(ncid);

end

clear ncid

end

%!demo 
%! % From real file :file:`${PROJECT_ID}MSG/msg-tb108_2006-08-01_15min.nc` ::
%! clear all
%! close all
%! varamma_startup
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! ncfilesset = 'normal';
%! [fullfilename] = MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour);
%! [TbMSG, Temps, Longitudes, Latitudes] = MSGread(ncfilesset, fullfilename);
%! whos

%!demo
%! % From real file :file:`${PROJECT_ID}MSG/extracted/2006/08/extracted-msg-tb108_2006-08-01_15min.nc` ::
%! clear all
%! close all
%! varamma_startup
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! ncfilesset = 'extracted';
%! [fullfilename] = MSGbuildfullfilename(ncfilesset, Annee, Mois, Jour);
%! [TbMSG, Temps, Longitudes, Latitudes] = MSGread(ncfilesset, fullfilename);
%! whos
