function [ij_cumul_concat, time_concat, Longitudes, Latitudes] = cumulEPSAT_concat(ncfilesset, lonmin, lonmax, latmin, latmax, longresol, latresol, Annee, Mois_start, Jour_start, Mois_stop, Jour_stop)

%CUMULEPSAT_CONCAT permet d'analyser les donnees EPSAT et de concatener les
%cumuls journaliers resultants. L'analyse s'effectue sur une seule
%saison, sur tous les fichiers ou entre deux dates predefinies.

%
%+
%
% ====================
% cumulEPSAT_concat.m
% ====================
%
% .. function:: cumulEPSAT_concat(ncfilesset, lonmin, lonmax, latmin, latmax, longresol, latresol, Annee, Mois_start, Jour_start, Mois_stop, Jour_stop)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * ncfilesset (en caracteres) : Type de fichier NetCDF que l'on cherche,
%     'normal' ou 'extracted'.
%   * lonmin : Borne inferieure des longitudes du domaine etudie.
%   * lonmax : Borne superieure des longitudes du domaine etudie.
%   * latmin : Borne inferieure des latitudes du domaine etudie.
%   * latmax : Borne superieure des latitudes du domaine etudie.
%   * longresol : Nouvelle resolution souhaitee (nombre de points) pour les
%     longitudes (0 pour garder la resolution d'origine).
%   * latresol : Nouvelle resolution souhaitee (nombre de points) pour les
%     latitudes (0 pour garder la resolution d'origine).
%   * Annee : Annee de la saison d'etude.
%   * Mois_start (Facultatif) : Mois du premier jour d'etude pour la
%     selection des fichiers.
%   * Jour_start (Facultatif) : Jour du premier jour d'etude pour la
%     selection des fichiers.
%   * Mois_stop (Facultatif) : Mois du dernier jour d'etude pour la
%     selection des fichiers.
%   * Jour_stop (Facultatif) : Jour du dernier jour d'etude pour la
%     selection des fichiers.
%
% - Donnees de sorties :
%
%   * ij_cumul_concat : Matrice de donnees (temps, longitudes,
%     latitudes)contenant les cumuls de precipitations concatenees des
%     differents jours d'etude.
%   * time_concat : Variable de temps, en jour julien, pour identifier les
%     jours etudies.
%   * Longitudes : Variable de longitudes dans le domaine selectionne.
%   * Latitudes : Variable de latitudes dans le domaine selectionne.
%
% Cette fonction permet d'analyser les donnees EPSAT et de concatener les
% cumuls de precipitations resultants. L'analyse s'effectue sur une seule
% saison, sur tous les fichiers ou entre deux dates predefinies.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :ref:`data_epsat`
%
% :ref:`varamma_startup.m`
%
% :func:`EPSATbuildfullfilename`
% :func:`extractedmatrixdata`
% :func:`spatialresolution`
% :func:`EPSATread`
% :func:`simul_epsat`
% :func:`cumulEPSAT_day`
%
% :func:`nonprecipperiods`
% :func:`MSGanalysiscrossvalidation`
% :func:`missingdaytonan`
%
% TODO
% ====
%
% usage of eomday
%
% heavy loop for files handling ... more elegant ?
%
% coding rule and describe demo
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110805T092658Z cratos (Linux)
%
%   * correct demo call
%   * remove varamma_startup call
%
% - jaclod 2011-07-29
%
%   * Revision finale du stage du mois de juillet 2011.
%
% - jaclod 2011-07-27
%
%   * Revision de la documentation et des commentaires.
%
% - jaclod 2011-07-21
%
%   * Creation en se basant sut la fonction intensityMSG_concat deja
%     existante.
%   * Compatibilite avec des fichiers 'extracted'.
%
%-

%%%%%%%%%%%%%%%%%
% Initialisation
%%%%%%%%%%%%%%%%%

% Appel de la variable global 'PROJECT_ID'.
global PROJECT_ID

% Sauvegarde de la variable 'Annee' sous forme de caracteres.
annee = num2str(Annee);

%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Boucles sur les fichiers
%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Les boucles se realisent de differentes facons selon la selection ou non
% de jours.

% Si le nombre d'arguments est superieur a 8 c'est qu'une selection est
% demandee. Sinon, on analyse tous les fichiers present dans le repertoire
% EPSAT.
if nargin > 8;
    
    % Creation d'un vecteur comportant le nombre maximum de jours que l'on
    % a dans chaque mois.
    maxjourmois = [31 29 31 30 31 30 31 31 30 31 30 31];
    
    %%%%%% Boucle sur les mois %%%%%%
    for Mois = Mois_start : Mois_stop;
        
        % Recuperation de la variable 'Mois' sous forme de caracteres.
        if Mois < 10;
            mois = ['0' num2str(Mois)];
        else
            mois = num2str(Mois);
        end
        
        % S'il s'agit du premier mois, le jour de depart sera celui entre
        % en argument, sinon ce sera le premier du mois.
        if Mois == Mois_start;
            Jour_ini = Jour_start;
        else
            Jour_ini = 1;
        end
        
        % S'il s'agit du dernier mois, le jour de fin sera celui entre
        % en argument, sinon ce sera le dernier jour possible du mois.
        if Mois == Mois_stop;
            Jour_fin = Jour_stop;
        else
            Jour_fin = maxjourmois(Mois);
        end
        
        %%%%%% Boucle sur les jours %%%%%%
        for Jour = Jour_ini : Jour_fin;
            
            % Recuperation de la variable 'Jour' sous forme de caracteres.
            if Jour < 10;
                jour = ['0' num2str(Jour)];
            else
                jour = num2str(Jour);
            end
            
            % Creation du chemin d'acces complet au fichier correspondant.
            [fullfilename] = EPSATbuildfullfilename(ncfilesset, annee, mois, jour);
            
            %%%%%% Analyse du fichier %%%%%%
            
            % Verification que le fichier du jour existe bien. Si ce n'est
            % pas le cas un message d'avertissement est donne. Sinon, on
            % peut faire l'analyse.
            % Cette verification differe selon le type de fichier en raison
            % d'un changement de repertoire et de nom.
            
            switch ncfilesset
                
                case 'normal'
                    repertoire = [PROJECT_ID 'EPSAT/' annee '/' mois '/'];
                    
                case 'extracted'
                    repertoire = [PROJECT_ID 'EPSAT/extracted/' annee '/' mois '/'];
                    
                otherwise
                    error('La variable ncfilesset doit etre ''normal'' ou ''extracted''.');
                    
            end
            
            path(path,repertoire);
            
            switch ncfilesset
                
                case 'normal'
                    if exist(['surf-rr_epsat-sg_multi-sat_010d_30min_' annee mois jour '_v3.1-02c.nc'],'file') == 2;
                        
                        % Message confirmant l'analyse du fichier.
                        disp(['iii : Analyse du fichier surf-rr_epsat-sg_multi-sat_010d_30min_' annee mois jour '_v3.1-02c.nc.']);
                        
                        % Lecture du fichier NetCDF, recuperation des 
                        % donnees et des variables.
                        [PluieEPSAT, Temps, Longitudes, Latitudes] = EPSATread(ncfilesset, fullfilename);
                        
                        % Extraction des donnees.
                        [PluieEPSAT, Temps, Longitudes, Latitudes] = extractedmatrixdata(PluieEPSAT, Temps, Longitudes, Latitudes, Temps(1), Temps(size(Temps,1)), lonmin, lonmax, latmin, latmax);
                        
                        %%%%%% Changement de resolution %%%%%%
                        % Si longresol et/ou latresol ont pour valeur 0, 
                        % alors on recupere la valeur de la resolution 
                        % initiale pour ne pas faire de changement.
                        if longresol == 0;
                            longresol = size(PluieEPSAT,2);
                        end
                        
                        if latresol == 0;
                            latresol = size(PluieEPSAT,3);
                        end
                        
                        % Si la resolution demandee est differente de celle
                        % initiale, alors on interpole les donnees avec la 
                        % fonction spatial resolution.
                        if longresol ~= size(PluieEPSAT,2) || latresol ~= size(PluieEPSAT,3);
                            [Longitudes, Latitudes, PluieEPSAT] = spatialresolution(Longitudes, Latitudes, PluieEPSAT, longresol, latresol);
                        end
                        
                        %%%%%% Calcul des cumuls %%%%%%
                        [cumulEPSAT] = cumulEPSAT_day(PluieEPSAT);
                        
                        %%%%%% Concatenation %%%%%%
                        % Sauvegarde des cumuls (la dimension 3 est ici le
                        % temps).
                        if Mois == Mois_start && Jour == Jour_start;
                            ij_cumul_concat = cumulEPSAT;
                        else
                            ij_cumul_concat = cat(3,ij_cumul_concat,cumulEPSAT);
                        end
                        
                        % Sauvegarde de l'information sur la date. On la 
                        % sauve en jour julien, il faut donc convertir par 
                        % rapport au temps fourni, en jours depuis le 1er 
                        % janvier 1960.
                        Tempsjourjulien = Temps(1) + datenum(1960,01,01);
                        if Mois == Mois_start && Jour == Jour_start;
                            time_concat = Tempsjourjulien;
                        else
                            time_concat = cat(2,time_concat,Tempsjourjulien);
                        end
                        
                    else
                        % Message d'avertissement en cas de non presence du
                        % fichier.
                        disp(['www : le fichier surf-rr_epsat-sg_multi-sat_010d_30min_' annee mois jour '_v3.1-02c.nc n''est pas present.']);
                    end
                    
                case 'extracted'
                    
                    if exist(['extracted-surf-rr_epsat-sg_multi-sat_010d_30min_' annee mois jour '_v3.1-02c.nc'],'file') == 2;
                        
                        % Message confirmant l'analyse du fichier.
                        disp(['iii : Analyse du fichier extracted-surf-rr_epsat-sg_multi-sat_010d_30min_' annee mois jour '_v3.1-02c.nc.']);
                        
                        % Lecture du fichier NetCDF, recuperation des 
                        % donnees et des variables.
                        [PluieEPSAT, Temps, Longitudes, Latitudes] = EPSATread(ncfilesset, fullfilename);
                        
                        % Pas d'extraction des donnees.
                        
                        %%%%%% Changement de resolution %%%%%%
                        % Si longresol et/ou latresol ont pour valeur 0, 
                        % alors on recupere la valeur de la resolution 
                        % initiale pour ne pas faire de changement.
                        if longresol == 0;
                            longresol = size(PluieEPSAT,2);
                        end
                        
                        if latresol == 0;
                            latresol = size(PluieEPSAT,3);
                        end
                        
                        % Si la resolution demandee est differente de celle
                        % initiale, alors on interpole les donnees avec la
                        % fonction spatial resolution.
                        if longresol ~= size(PluieEPSAT,2) || latresol ~= size(PluieEPSAT,3);
                            [Longitudes, Latitudes, PluieEPSAT] = spatialresolution(Longitudes, Latitudes, PluieEPSAT, longresol, latresol);
                        end
                        
                        %%%%%% Calcul des cumuls %%%%%%
                        [cumulEPSAT] = cumulEPSAT_day(PluieEPSAT);
                        
                        %%%%%% Concatenation %%%%%%
                        % Sauvegarde des cumuls (la dimension 3 est ici le
                        % temps).
                        if Mois == Mois_start && Jour == Jour_start;
                            ij_cumul_concat = cumulEPSAT;
                        else
                            ij_cumul_concat = cat(3,ij_cumul_concat,cumulEPSAT);
                        end
                        
                        % Sauvegarde de l'information sur la date. On la 
                        % sauve en jour julien, il faut donc convertir par 
                        % rapport au temps fourni, en jour depuis le 1er 
                        % janvier 1960.
                        Tempsjourjulien = Temps(1) + datenum(1960,01,01);
                        if Mois == Mois_start && Jour == Jour_start;
                            time_concat = Tempsjourjulien;
                        else
                            time_concat = cat(2,time_concat,Tempsjourjulien);
                        end
                        
                    else
                        % Message d'avertissement en cas de non presence du
                        % fichier.
                        disp(['www : le fichier extracted-surf-rr_epsat-sg_multi-sat_010d_30min_' annee mois jour '_v3.1-02c.nc n''est pas present.']);
                    end
                    
                otherwise
                    % Cas impossible. Erreur deja donnee.
            end
            
        end
        
    end
    
else
    
    %%%%% Recherche des mois de donnees %%%%%
    % Repertoire correspondant aux fichiers EPSAT de l'annee en question
    % differents selon le type de fichier.
    switch ncfilesset
        
        case 'normal'
            repertoireEPSATsaison = [PROJECT_ID 'EPSAT/' annee];
            
        case 'extracted'
            repertoireEPSATsaison = [PROJECT_ID 'EPSAT/extracted/' annee];
        
        otherwise
    end
    
    path(path,repertoireEPSATsaison);
    
    % On cherche les dossier dans ce dernier repertoire correspondant aux
    % mois dont nous disposons des donnees.
    listdir = dir(repertoireEPSATsaison);
    
    % Nombre de dossier. Attention les deux premiers resultats sont '.' et
    % '..' et ne compte donc pas comme dossier de fichiers.
    nbdir = numel(listdir)-2;
    
    %%%%% Boucle sur les mois %%%%%
    for numdir = 1 : nbdir;
        
        % Recuperation du numero du mois sous forme de caracteres.
        mois = listdir(numdir+2).name;
        
        % Repertoire du mois correspondant.
        repertoireEPSATmois = [repertoireEPSATsaison '/' mois];
        
        path(path,repertoireEPSATmois);
        
        %%%%% Recherche des fichiers netCDF %%%%%
        ext = '*.nc';
        chemin = fullfile(repertoireEPSATmois,ext);
        listncfiles = dir(chemin);
        
        nbfiles = numel(listncfiles);
        
        %%%%% Boucle sur les fichiers, les jours %%%%%
        for numfiles = 1 : nbfiles;
            
            % Recuperation du nom du fichier et de son chemin d'acces
            % complet.
            fullfilename = [repertoireEPSATmois '/' listncfiles(numfiles).name];
            
            % Message confirmant l'analyse du fichier.
            disp(['iii : Analyse du fichier ' listncfiles(numfiles).name '.']);
            
            % Lecture du fichier NetCDF, recuperation des donnees et
            % des variables.
            [PluieEPSAT, Temps, Longitudes, Latitudes] = EPSATread(ncfilesset, fullfilename);
            
            switch ncfilesset
                
                case 'normal'
                    % Extraction des donnees.
                    [PluieEPSAT, Temps, Longitudes, Latitudes] = extractedmatrixdata(PluieEPSAT, Temps, Longitudes, Latitudes, Temps(1), Temps(size(Temps,1)), lonmin, lonmax, latmin, latmax);
                
                case 'extracted'
                    % Pas d'extraction.
                    
                otherwise
            end
            
            %%%%%% Changement de resolution %%%%%%
            % Si longresol et/ou latresol ont pour valeur 0, alors on
            % recupere la valeur de la resolution initiale pour ne pas
            % faire de changement.
            if longresol == 0;
                longresol = size(PluieEPSAT,2);
            end
            
            if latresol == 0;
                latresol = size(PluieEPSAT,3);
            end
            
            % Si la resolution demandee est differente de celle
            % initiale, alors on interpole les donnees avec la fonction
            % spatial resolution.
            if longresol ~= size(PluieEPSAT,2) || latresol ~= size(PluieEPSAT,3);
                [Longitudes, Latitudes, PluieEPSAT] = spatialresolution(Longitudes, Latitudes, PluieEPSAT, longresol, latresol);
            end
            
            %%%%%% Calcul des cumuls %%%%%%
            [cumulEPSAT] = cumulEPSAT_day(PluieEPSAT);
            
            %%%%%% Concatenation %%%%%%
            
            % Sauvegarde des cumuls (la dimension 3 est ici le temps).
            if numdir==1 && numfiles==1;
                ij_cumul_concat = cumulEPSAT;
            else
                ij_cumul_concat = cat(3,ij_cumul_concat,cumulEPSAT);
            end
            
            % Sauvegarde de l'information sur la date. On la sauve en jour
            % julien, il faut donc convertir par rapport au temps fourni,
            % en jours depuis le 1er janvier 1960.
            Tempsjourjulien = Temps(1) + datenum(1960,01,01);
            if numdir==1 && numfiles==1;
                time_concat = Tempsjourjulien;
            else
                time_concat = cat(2,time_concat,Tempsjourjulien);
            end
            
        end
        
    end
    
end

% On passe le temps en premiere dimension pour plus de concordance avec les
% autres variables.
ij_cumul_concat = permute(ij_cumul_concat,[3 1 2]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%

end

%!demo
%! clear all
%! close all
%! varamma_startup
%! more off
%! [ij_cumul_concat, time_concat, Longitudes, Latitudes] = cumulEPSAT_concat('normal',-20, 0, 0, 20, 200, 200, 2006, 07, 26, 07, 31);
