function [hovdata] = hovmullerlonorlat(data,dim1,dim2,dim3,numdimtomean,centralvalue,extmeandim, nomvar)

%hovmullerlonorlat permet de realiser un diagramme de hovmuller a partir
%d'une matrice 3D (temps, longitudes, latitudes). Celui-ci peut-etre
%latitudes vs temps ou temps vs longitudes.

%
%+
%
% ====================
% hovmullerlonorlat.m
% ====================
%
% .. function:: hovmullerlonorlat(data,dim1,dim2,dim3,numdimtomean,centralvalue,extmeandim,nomvar)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * data : Matrice de donnees 3D (temps, longitudes, latitudes).
%   * dim1 : Variable de la dimension 1 de la matrice 'data', c'est-a-dire
%     le temps.
%   * dim2 : Variable de la dimension 2 de la matrice 'data', c'est-a-dire
%     les longitudes.
%   * dim3 : Variable de la dimension 3 de la matrice 'data', c'est-a-dire
%     les latitudes.
%   * numdimtomean : Numero de la dimension spatial sur laquelle il faudra
%     moyenner. (Ex : Pour un diagramme latitudes vs temps, il faut
%     moyenner sur les longitudes soit la dimension 2).
%   * centralvalue : Valeur centrale du moyennage sur la dimension
%     correspondante (en degrees + si N/E ou - si S/W).
%   * extmeandim : Etendue du moyennage autour de la valeur centrale (en
%     degrees).
%   * nomvar (caracteres) : Nom et unite de la donnee etudiee ici 
%     (Ex : 'cumuls EPSAT (mm)'). 
%
% - Donnees de sorties :
%
%   * hovdata : Matrice 2D comportant les donnees du diagramme de
%     hovmuller. La premiere dimension est le temps et la dimension
%     spatiale du diagramme.
%
% Cette fonction permet d'analyser les donnees MSG et de concatener les
% intensites resultantes en sortie. L'analyse s'effectue sur une seule
% saison, sur tous les fichiers ou entre deux dates predefinies.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% use datetick
%
% check if demo latitude correct
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110804T123916Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add demo latitude
%
% - jaclod 2011-07-27
%
%   * Revision de la documentation et des commentaires.
%   * Remplacement des arguments d'entrees 'minmeandim' et 'maxmeandim' par
%     'centralvalue' et 'extmeandim' et modification des titres.
%
% - jaclod 2011-07-21
%
%   * Modification de l'affichage des donnees temporelles sur l'axe
%     correspondant.
%   * Ajour de la documentation et des commentaires.
%
% - jaclod 2011-07-20
%
%   * Creation.
%
%-

if nargin~=8;
    error('Tous les arguments n''ont pas ete donnes.')
end

if size(size(data),2) ~= 3;
    error('Les donnees doivent etre dans une matrice a 3 dimensions.')
end

if numdimtomean ~= 2 && numdimtomean ~= 3;
    error('Le moyennage ne se fait que sur l''une des dimensions spatiales de la matrice de donnees (temps, longitudes, latitudes).');
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Creation des bornes sur la dimension moyenne
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

minmeandim = centralvalue - extmeandim/2;
maxmeandim = centralvalue + extmeandim/2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Extraction des donnees concernes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% On cherche les indices entre lesquelles il faut prendre les donnees. On
% extrait ensuite les donnees correspondantes.
if numdimtomean == 2;
    
    %%%%% Recherche des indices %%%%%
    indicemin = find(dim2 >= minmeandim,1,'first');
    indicemax = find(dim2 <= maxmeandim,1,'last');
    
    %%%%% Extraction des donnees %%%%%
    extracteddata = data(1:size(data,1),indicemin:indicemax,1:size(data,3));
    
elseif numdimtomean == 3;
    
    %%%%% Recherche des indices %%%%%
    indicemin = find(dim3 >= minmeandim,1,'first');
    indicemax = find(dim3 <= maxmeandim,1,'last');
    
    %%%%% Extraction des donnees %%%%%
    extracteddata = data(1:size(data,1),1:size(data,2),indicemin:indicemax);
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Moyennage sur la dimension spatiale selectionne
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if numdimtomean == 2;
    hovdata = squeeze(mean(extracteddata,2));
elseif numdimtomean == 3;
    hovdata = squeeze(mean(extracteddata,3));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dessin du diagramme de Hovmuller
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% Ouverture d'une figure
h=figure;

%%%%% Calculs pour l'affichage de la coordonnee temporelle %%%%%
% Nombre de 'tick' temporel maximum.
nbtickmax = 10;

% Nombre de pas de temps.
nbtimestep = size(data,1);

% On cherche le pas d'affichage des pas de temps pour ne pas depasser la
% limite autorisee (on prend l'arrondi superieur avec la fonction 'ceil').
tickstep = ceil(nbtimestep / nbtickmax);

% On garde les numero dans temps a afficher.
numtime = 1 : tickstep : nbtimestep;

% On enregistre les futures 'ticklabel' sous forme de caracteres.
time = datestr(dim1(numtime),'mmm dd');

if numdimtomean == 2;
    
    %%%%% Image du diagramme %%%%%
    % On veut un diagramme latitudes vs temps, il faut donc transposer la
    % matrice de donnees.
    imagesc(dim1,dim3,hovdata');
    set(gca,'ydir','normal');
    
    %%%%% Axes du diagramme %%%%%
    set(gca,'xtick',dim1(numtime));
    set(gca,'xticklabel',time);
    ylabel('Latitudes');
    
    %%%%% Titre du diagramme %%%%%
    title(['Diagramme de hovmuller des ' nomvar ' sur ' num2str(extmeandim) ' degres autour de ' num2str(centralvalue) ' en longitudes']);
    
elseif numdimtomean == 3;
    
    %%%%% Image du diagramme %%%%%
    % On veut un diagramme temps vs longitudes.
    imagesc(dim2,dim1,hovdata);
    set(gca,'ydir','normal');
    
    %%%%% Axes du diagramme %%%%%
    xlabel('Longitudes');
    set(gca,'ytick',dim1(numtime));
    set(gca,'yticklabel',time);
    
    %%%%% Titre du diagramme %%%%%
    title(['Diagramme de hovmuller des ' nomvar ' sur ' num2str(extmeandim) ' degres autour de ' num2str(centralvalue) ' en latitudes']);
end

%%%%% Ajout d'une barre de couleur %%%%%
colorbar

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end

%!demo
%! % school example longitudes
%! clear all
%! close all
%! data(1,:,:) = reshape(1:100,10,10);
%! for i=2:50;
%!     data(i,:,:)=data(i-1,:,:)+2;
%! end
%! dim1 = datenum(2011,07,27) : datenum(2011,07,27)+49;
%! dim2 = -4.5:4.5;
%! dim3 = 0.5:9.5;
%! numdimtomean=2;
%! centralvalue=0; 
%! extmeandim=2;
%! nomvar='valeurs tests pour la demonstration';
%! [hovdata] = hovmullerlonorlat(data, dim1, dim2, dim3, numdimtomean, centralvalue, extmeandim, nomvar);

%!demo
%! % school example latitude
%! clear all
%! close all
%! data(1,:,:) = reshape(1:100,10,10);
%! for i=2:50;
%!     data(i,:,:)=data(i-1,:,:)+2;
%! end
%! dim1 = datenum(2011,07,27) : datenum(2011,07,27)+49;
%! dim2 = -4.5:4.5;
%! dim3 = 0.5:9.5;
%! numdimtomean=3;
%! centralvalue=0; 
%! extmeandim=3;
%! nomvar='valeurs tests pour la demonstration';
%! [hovdata] = hovmullerlonorlat(data, dim1, dim2, dim3, numdimtomean, centralvalue, extmeandim, nomvar);
