function [mat_intensity_precip] = int2precip(mat_intensity, type, Longitudes, Latitudes)

%int2precip est une fonction permettant de passer de donnees d'intensites
%en donnees de precipitations en mm sur le domaine 0-20W 0-20N.

%
%+
%
% ============
% int2precip.m
% ============
%
% .. function:: int2precip(mat_intensity, type, Longitudes, Latitudes)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * mat_intensity : Matrice contenant les intensites sur la zone 0-20W et
%     0-20N, de dimension longitudes, latitudes si elle est 2D ou temps,
%     longitudes, latitudes si elle est 3D.
%   * type : Type de formules a utiliser, 'global' pour utiliser la meme
%     sur l'ensemble du domaine ou 'regional' pour utiliser les formules
%     sur les 4 sous regions etudies.
%   * Longitudes (si type = 'regional') : Variable de longitudes des
%     donnees.
%   * Latitudes (si type = 'regional') : Variable de latitudes des
%     donnees.
%
% - Donnees de sorties :
%
%   * mat_intensity_precip : Matrice de donnees de precipitations dont les
%     dimensions sont celle de la matrice d'intensites initiales.
%
% Cette fonction permet de passer de donnees d'intensites en donnees de 
% precipitations en mm sur le domaine 0-20W 0-20N.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :ref:`varamma_startup.m`
%
% :func:`MSGbuildfullfilename`
% :func:`MSGread`
% :func:`intensityMSG_day`
% :func:`intensityMSG_concat`
%
% :func:`nonprecipperiods`
% :func:`missingdaytonan`
%
% TODO
% ====
%
% use :func:`extractedmatrixdata`
% use :func:`spatialresolution`
%
% more explanation on demo
%
% demo wih simulation
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - jaclod 2011-07-29
%
%   * Creation.
%
%-

% Application des formules pour passer des intensites en precipitations
% (formules basees sur la validation croisee entre les intensites obtenues 
% par l'analyse des donnees MSG et des donnees EPSAT sur une zone de -20 a
% 0 en longitudes et de 0 a 20 en latitudes. Dans chaque cas, la formule
% moyenne est obtenue a partir des proches resultats pour un domaine donnee
% des regressions lineaires, cf. MSGanalysiscrossvalidation).
switch type
    
    case 'global'
        % Dans ce cas, on souhaite appliquer la meme formule a l'ensemble
        % du domaine (0-20W et 0-20N). Nous ne gardons que le facteur
        % d'echelle, pour garder les precipitations nulles,sur la formule 
        % moyenne suivante :
        % precipitations (mm) = 0.0327 * intensites + 1.02.
        mat_intensity_precip = 0.0327 * mat_intensity;
        
    case 'regional'
        % Dans ce cas, on souhaite appliquer la formule sur differents
        % domaines etudies (Il s'agit des regions 10-20W 10-20N, 10-20W
        % 0-10N, 0-20W 5-10N et enfin 0-20W 0-5N).
        
        % Initialisation de la matrice de donnees de precipitations.
        mat_intensity_precip = zeros(size(mat_intensity));
        
        % On applique le facteur d'echelle de la formule moyenne 
        % correspondante a chaque region.
        % Region 10-20W 10-20N :
        
        % Recuperation des indices des bornes de la region.
        indlonmin = find(Longitudes >= -20,1,'first');
        indlonmax = find(Longitudes <= -10,1,'last');
        indlatmin = find(Latitudes >= 10,1,'first');
        indlatmax = find(Latitudes <= 20,1,'last');
        
        % Application, pour cette region, du facteur de la formule
        % moyenne :
        % Precipitations (mm) = 0.028035 * intensites + 0.66.
        if size(size(mat_intensity),2)==3;
            
            % Matrice 3D avec une premiere dimension temporelle.
            mat_intensity_precip(:,indlonmin:indlonmax,indlatmin:indlatmax) = 0.028035 * mat_intensity(:,indlonmin:indlonmax,indlatmin:indlatmax);
            
        elseif size(size(mat_intensity),2)==2;
            
            % Matrice 2D.
            mat_intensity_precip(indlonmin:indlonmax,indlatmin:indlatmax) = 0.028035 * mat_intensity(indlonmin:indlonmax,indlatmin:indlatmax);
            
        else
            error('Les donnees d''intensites doivent etre dans une matrice 2D ou 3D avec une premiere dimension temporelle.')
        
        end
        
        % Region 0-10W 10-20N :
        
        % Recuperation des indices des bornes de la region.
        indlonmin = find(Longitudes >= -10,1,'first');
        indlonmax = find(Longitudes <= 0,1,'last');
        indlatmin = find(Latitudes >= 10,1,'first');
        indlatmax = find(Latitudes <= 20,1,'last');
        
        % Application, pour cette region, du facteur de la formule
        % moyenne :
        % Precipitations (mm) = 0.028126 * intensites + 0.55.
        % (On remarque que cette formule, ne change pas beaucoup par
        % rapport a la precedent qui est a la meme latitude. La constante
        % change probablement a cause des precipitations sous-estime avec
        % notre analyse sur l'ocean).
        if size(size(mat_intensity),2)==3;
            
            % Matrice 3D avec une premiere dimension temporelle.
            mat_intensity_precip(:,indlonmin:indlonmax,indlatmin:indlatmax) = 0.028126 * mat_intensity(:,indlonmin:indlonmax,indlatmin:indlatmax);
            
        elseif size(size(mat_intensity),2)==2;
            
            % Matrice 2D.
            mat_intensity_precip(indlonmin:indlonmax,indlatmin:indlatmax) = 0.028126 * mat_intensity(indlonmin:indlonmax,indlatmin:indlatmax);
            
        else
            % Erreur deja donnee.
        end
        
        % Region 0-20W 5-10N :
        
        % Recuperation des indices des bornes de la region.
        indlonmin = find(Longitudes >= -20,1,'first');
        indlonmax = find(Longitudes <= 0,1,'last');
        indlatmin = find(Latitudes >= 5,1,'first');
        indlatmax = find(Latitudes <= 10,1,'last');
        
        % Application, pour cette region, du facteur de la formule
        % moyenne :
        % Precipitations (mm) = 0.0395 * intensites + 2.
        if size(size(mat_intensity),2)==3;
            
            % Matrice 3D avec une premiere dimension temporelle.
            mat_intensity_precip(:,indlonmin:indlonmax,indlatmin:indlatmax) = 0.0395 * mat_intensity(:,indlonmin:indlonmax,indlatmin:indlatmax);
            
        elseif size(size(mat_intensity),2)==2;
            
            % Matrice 2D.
            mat_intensity_precip(indlonmin:indlonmax,indlatmin:indlatmax) = 0.0395 * mat_intensity(indlonmin:indlonmax,indlatmin:indlatmax);
            
        else
            % Erreur deja donnee.
        end
        
        % Region 0-20W 0-5N :
        
        % Recuperation des indices des bornes de la region.
        indlonmin = find(Longitudes >= -20,1,'first');
        indlonmax = find(Longitudes <= 0,1,'last');
        indlatmin = find(Latitudes >= 0,1,'first');
        indlatmax = find(Latitudes <= 5,1,'last');
        
        % Application, pour cette region, du facteur de la formule
        % moyenne :
        % Precipitations (mm) = 0.055 * intensites + 0.56.
        if size(size(mat_intensity),2)==3;
            
            % Matrice 3D avec une premiere dimension temporelle.
            mat_intensity_precip(:,indlonmin:indlonmax,indlatmin:indlatmax) = 0.055 * mat_intensity(:,indlonmin:indlonmax,indlatmin:indlatmax);
            
        elseif size(size(mat_intensity),2)==2;
            
            % Matrice 2D.
            mat_intensity_precip(indlonmin:indlonmax,indlatmin:indlatmax) = 0.055 * mat_intensity(indlonmin:indlonmax,indlatmin:indlatmax);
            
        else
            % Erreur deja donnee.
        end
        
    otherwise
        error('Le type d''application de formules ne peut qu''etre ''global'' ou ''regional''.')
    
end

end

%!demo
%! [ij_intensity_concat, time_concat, Longitudes, Latitudes] = intensityMSG_concat('extracted', 0, 0, 0, 0, 0, 0, 2006, 08, 01, 08, 07);
%! [ij_intensity_concat_precip] = int2precip(ij_intensity_concat, 'global');
