function [mat_withnan, dimtemp_complete] = missingdaytonan(mat_ini,dimtemp)

%MISSINGDAYTONAN est une fonction permettant, pour des donnees journalieres
%concatenees, de remplir les jours manquants par des 'NaN' dans la matrice
%de donnees et de mettre a jour la matrice temporelle.

%
%+
%
% ==================
% missingdaytonan.m
% ==================
%
% .. function:: missingdaytonan(mat_ini,dimtemp)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * mat_ini : Matrice 3D de donnees initiales dont la premiere dimension
%     est le temps.
%   * dimtemp : Variable de la dimension temporelle de la matrice de
%     donnees initiales, en jour julien.
%
% - Donnees de sorties :
%
%   * mat_withnan : Matrice 3D de donnees finales avec des 'NaN' pour les
%     jours initialement manquants.
%   * dimtemp_complete : Variable de la dimension temporelle de la matrice
%     de donnees finales, en jour julien.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :func:`cumulEPSAT_concat`
% :func:`intensityMSG_concat`
%
% :func:`box5x5serietemp`
%
% TODO
% ====
%
% use eomday
%
% describe demo
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - jaclod 2011-07-27
%
%   * Ajout de la documentation, des commentaires et de la demonstration.
%
% - jaclod 2011-07-26
%
%   * Creation.
%
%-

%%%%%%%%%%%%%%%%%
% Initialisation
%%%%%%%%%%%%%%%%%

% Matrice comportant le nombre de jours maximum dans chaque mois.
maxjourmois = [31 29 31 30 31 30 31 31 30 31 30 31];

% Matrice, aux dimensions spatiales de la matrice initiale, ne comportant
% que des 'NaN'.
nanmat = zeros(size(mat_ini,2),size(mat_ini,3));
nanmat(nanmat==0)=NaN;
nanmat = permute(nanmat,[3 1 2]);

% Passage de l'information temporelle dans une matrice separant chaque
% element de la date.
tempvec = datevec(dimtemp);

% Recuperation du premier et dernier mois de donnees.
Mois_start = tempvec(1,2);
Mois_stop = tempvec(size(tempvec,1),2);

% Initialisation des donnees de sorties qui seront modifiees tout au long
% de cette fonction.
mat_withnan = mat_ini;
dimtemp_complete = dimtemp;

%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%
% Boucle sur les mois
%%%%%%%%%%%%%%%%%%%%%%

for Mois = Mois_start : Mois_stop;

    % Tant que le mois ne compte pas son nombre de jours maximum, on
    % cherche les jours manquants.
    while size(find(tempvec(:,2)==Mois),1) ~= maxjourmois(Mois);

        Jour = 1;

        % Verification sur chaque jour.
        while Jour <= maxjourmois(Mois);

            % On recherche les indices des dates du mois dans la matrice
            % 'tempvec'.
            indmois = find(tempvec(:,2)==Mois);

            % Si on ne trouve pas le jour dans le mois, on continue. Sinon
            % on passe au jour suivant.
            if isempty(find(tempvec(indmois,3)==Jour, 1));

                % Il faut trouver a quel endroit il faut ajouter des NaN.
                % On cherche le jour present precedent ou, a defaut, le
                % jour suivant.
                Jourprec = Jour - 1;
                indprec = find(tempvec(indmois,3)==Jourprec);

                while Jourprec ~= 0 && isempty(indprec) == 1;

                    Jourprec = Jourprec - 1;
                    indprec = find(tempvec(indmois,3)==Jourprec);

                end

                % S'il n'y avait pas de jour precedent, on cherche parmi
                % les suivants.
                if isempty(indprec) == 1;

                    Joursuiv = Jour + 1;
                    indsuiv = find(tempvec(indmois,3)==Joursuiv);

                    while Joursuiv ~= maxjourmois(Mois) && isempty(indsuiv) == 1;

                        Joursuiv = Joursuiv + 1;
                        indsuiv = find(tempvec(indmois,3)==Joursuiv);

                    end

                    % Si on a l'indice suivant, on en deduit l'indice
                    % precedent.
                    indprec = indsuiv - 1;

                else

                    % Si on a l'indice precedent, on en deduit l'indice
                    % suivant.
                    indsuiv = indprec + 1;

                end

                % Ajout de Nan entre les jours precedents et suivants.
                indinf = indmois(1)-1+indprec;
                indsup = indmois(1)-1+indsuiv;

                % L'ajout different selon l'emplacement du jour par rapport
                % a l'ensemble. Il peut etre encercle ou sur une extremite.
                if indinf ~= 0 && indsup <= size(mat_withnan,1);

                    % Dans ce cas, on est entoure par d'autres jours
                    % presents.
                    mat_withnan = cat(1,mat_withnan(1:indinf,:,:),nanmat(1,:,:),mat_withnan(indsup:size(mat_withnan,1),:,:));
                    dimtemp_complete = cat(2,dimtemp_complete(1:indinf),datenum(tempvec(1,1),Mois,Jour),dimtemp_complete(indsup:size(dimtemp_complete,2)));

                else

                    % Dans ce cas on est sur l'une des extrimite. Le suite
                    % depend s'il s'agit du premier ou du dernier jour.
                    if indinf == 0;

                        % Dans ce cas, ce jour manquant est le premier
                        % jour.
                        mat_withnan = cat(1,nanmat,mat_withnan(1:size(mat_withnan,1),:,:));
                        dimtemp_complete = cat(2,datenum(tempvec(1,1),Mois,Jour),dimtemp_complete(indsup:size(dimtemp_complete,2)));

                    elseif indsup > size(mat_withnan,1);

                        % Dans ce cas ce jour manquant est le dernier jour.
                        mat_withnan = cat(1,mat_withnan(1:indinf,:,:),nanmat);
                        dimtemp_complete = cat(2,dimtemp_complete(1:indinf),datenum(tempvec(1,1),Mois,Jour));

                    end

                end

                % Mise a jour des informations temporelles.
                tempvec = datevec(dimtemp_complete);

            end

            % Modification de la variable 'Jour', on s'interesse au jour
            % suivant.
            Jour = Jour + 1;

        end

    end

end

%%%%%%%%%%%%%%%%%%%%%%

end

%!demo
%! clear all
%! close all
%! varamma_startup
%! more off
%! [ij_intensity_concat, time_concat, Longitudes, Latitudes] = intensityMSG_concat('extracted', 0, 0, 0, 0, 200, 200, 2006, 09, 01, 09, 30);
%! [ij_intensity_concat_withnan, time_concat_complete] = missingdaytonan(ij_intensity_concat, time_concat)
%! whos('ij_intensity_concat', 'time_concat', 'ij_intensity_concat_withnan', 'time_concat_complete');
