function [lon_value, lat_value, datestr_value, lai_value]=simul_lai(index_simulation)

%SIMUL_LAI fill array LAI 3d array and associated arrays lat, lon, date
%          with simulated data

%
%+
%
% ===========
% simul_lai.m
% ===========
%
% .. function:: simul_lai(index_simulation)
%
% DESCRIPTION
% ===========
%
%    :param index_simulation: 1 or 2
%    :type index_simulation: int16
%    :raise index_simulation: required
%
%    :returns: 0 if ok or -1 if error
%    :rtype: integer
%
% Charge en mmoire un tableau simul **lai_value** de LAI dans :
%
% Simulation #1
%    la zone gographique [20E,10E] [10N,20N] avec un point tous les 2 en
%    latitude et 5 en longitude et dans la zone temporelle 20010101-20011231
%    avec un point ts les 50 jours.
%
% Simulation #2
%    la zone gographique [++E,++E] [++N,++N] avec 860 points en latitude
%    et 874 points en longitude dans la zone temporelle 20010101-20011231
%    avec un point ts les 8 jours.
%
% Les longitudes sont stockes dans le tableau **lon_value**.
%
% Les latitudes sont stockes dans le tableau **lat_value**.
%
% Les dates au format `yyyymmdd` sont stocks dans le tableau **datestr_value**.
%
% EXAMPLES
% ========
%
% From scratch to create short array of LAI and associated arrays lat, long
% and datestr::
%
%   $ octave
%   octave> varamma_startup
%   octave> more off
%   octave> index_simulation=1;
%   octave> [lon_value, lat_value, datestr_value, lai_value]=simul_lai(index_simulation);
%
% To write these arrays in
% file:`${PROJECT_OD}/LAI/laisen2001_write_lai_float.txt`::
%
%   octave> result=write_lai(lon_value, lat_value, datestr_value, lai_value);
%
% From scratch to create long array of LAI and associated arrays lat, long
% and datestr::
%
%   $ octave
%   octave> varamma_startup
%   octave> more off
%   octave> [lon_value, lat_value, datestr_value, lai_value]=simul_lai(2);
%
% To write these arrays in
% file:`${PROJECT_OD}/LAI/lai2001_write_lai_float.txt`::
%
%   octave> result=write_lai(lon_value, lat_value, datestr_value, lai_value);
%
% SEE ALSO
% ========
%
% :ref:`guide data LAI <data_lai>`
%
% :func:`simul_lai`
% :func:`write_lai`
%
% TODO
% ====
%
% des valeurs de LAI plus ralistes y compris des NaN
%
% check argument
%
% EVOLUTIONS
% ==========
%
% $Id: simul_lai.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
% - fplod 20101202T142356Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add parameter information in header
%
% - fplod 20100830T152107Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add argument index_simulation
%   * add simulation #2 to produce arrays with the same supposed dimension
%     of real file :file:`$PROJECT_ID/LAI:lai2001_float.txt`
%
% - fplod 20100826T120800Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation because real files are big (193 Mo) so need some small LAI
%     data to test scientific application
%
%-
%
result=-1;
%
% dfinition de la zone gographique : les coins en degr et les rsolutions
if (index_simulation == 1);
   % ici une boite [20E,10E] [10N,20N] et un point tous les 2 en latitude
   % et 5 en longitude
   lonmin_value=-20.;
   lonmax_value=-10.;
   latmin_value=10.;
   latmax_value=20.;
   lat_delta = 2.;
   lon_delta = 5.;
elseif (index_simulation == 2 )
   %lon_value=transpose(linspace(-18.168,-10.518,874));
   lonmin_value=-18.168;
   lonmax_value=-10.518;
   %lat_value=transpose(linspace(10.004,17.996,860));
   latmin_value=10.004;
   latmax_value=17.996;
   lat_delta = 0.0092930;
   lon_delta = 0.0087529;
else
   error(['eee : unknow simulation ' num2str(index_simulation)]);
end
%
% dfinition de la zone temporelle : l'anne et la rsolution
if (index_simulation == 1)
   % ici une valeur tous les 50 jours pour 2001
   yyyy_value=2001;
   datestr_delta=50;
elseif (index_simulation == 2 )
   % ici une valeur tous les 8 jours pour 2001
   yyyy_value=2001;
   datestr_delta=8;
else
   error(['eee : unknow simulation ' num2str(index_simulation)]);
end
% cration du tableau des longitudes
lon_value=transpose(lonmin_value:lon_delta:lonmax_value);
clear lonmin_value
clear lonmax_value
clear lon_delta
nb_lon=size(lon_value,1);
%
% cration du tableau des latitudes
lat_value=transpose(latmin_value:lat_delta:latmax_value);
clear latmin_value
clear latmax_value
clear lat_delta
nb_lat=size(lat_value,1);
%
doy_value=datenum(yyyy_value,1,1):datestr_delta:datenum(yyyy_value,12,eomday(yyyy_value,12));
clear yyyy_value
%
% conversion datenum (unit octave/matlab) en format "yyyymmdd"
datestr_value=datestr(doy_value,'yyyymmdd');
clear doy_value
nb_datestr=size(datestr_value,1);
%
% cration de tableau LAI
lai_value=zeros(nb_datestr,nb_lat,nb_lon);
lai_value(:,:,:)=NaN;
for index_datestr=1:nb_datestr
   for index_lat=1:nb_lat
      for index_lon=1:nb_lon
          lai_value(index_datestr,index_lat,index_lon)=(index_datestr+index_lat+index_lon)/100.;
      end
   end
end
clear nb_lat
clear index_lat
clear nb_lon
clear index_lon
clear nb_datestr
clear index_datestr
%
result=0;
%
end
