function [lon_value, lat_value, datejul_value, datestr_value, lai_value]=simul_lai_2d(index_simulation)

%SIMUL_LAI_2D fill array LAI 2d array and associated arrays lat, lon, date
%          with simulated data

%
%+
%
% ==============
% simul_lai_2d.m
% ==============
%
% .. function:: simul_lai_2d(index_simulation)
%
% DESCRIPTION
% ===========
%
%    :param index_simulation: 1 or 2
%    :type index_simulation: int8
%    :raise index_simulation: required
%
% Charge en mmoire un tableau 2D simul **lai_value** de LAI dans :
%
% Simulation #1
%    la zone gographique [20E,10E] [10N,20N] avec un point tous les 2 en
%    latitude et 5 en longitude et dans la zone temporelle 20010101-20011231
%    avec un point ts les 30 jours. ++ en biais avec un dcalage de .5 degr en longitude
%
% Simulation #2
%    la zone gographique [++E,++E] [++N,++N] avec 860 points en latitude
%    et 874 points en longitude dans la zone temporelle 20010101-20011231
%    avec un point ts les 8 jours. ++ en biais avec un dcalage de .5 degr en longitude
%
% Les longitudes sont stockes dans le tableau **lon_value**.
%
% Les latitudes sont stockes dans le tableau **lat_value**.
%
% Les dates au format `yyyymmdd` sont stocks dans le tableau **datestr_value**.
%
% EXAMPLES
% ========
%
% From scratch to create short array of LAI and associated arrays lat, long
% and datestr:
%
% see demo 1
%
% To plot the grid::
%
%   octave> showgrid(lon_value, lat_value);
%
% To write these arrays in
% file:`${PROJECT_OD}/LAI/laisen2001_write_lai_2d_float.txt`::
%
%   octave> result=write_lai_2d(lon_value, lat_value, datestr_value, lai_value);
%
% From scratch to create long array of LAI and associated arrays lat, long
% and datestr:
%
% see demo 2
%
% To plot the grid::
%
%   octave> result=showgrid(lon_value, lat_value);
%
% To write these arrays in
% file:`${PROJECT_OD}/LAI/laisen2001_write_lai_2d_float.txt`::
%
%   octave> result=write_lai_2d(lon_value, lat_value, datejul_value, datestr_value, lai_value);
%
% SEE ALSO
% ========
%
% :ref:`guide data LAI <data_lai>`
%
% :func:`simul_lai_2d`
% :func:`write_lai_2d`
%
% TODO
% ====
%
% des valeurs de LAI plus ralistes y compris des NaN
%
% returned values when error
%
% EVOLUTIONS
% ==========
%
% $Id: simul_lai_2d.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
%
% - fplod 20110708T164042Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add datejul_value output
%
% - fplod 20110302T153846Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * examples moved to demo
%
% - fplod 20101208T103329Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * check argument
%
% - fplod 20101206T152338Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * check argument
%
% - fplod 20101206T105346Z adonis.locean-ipsl.upmc.fr (Linux)
%
%   * cleanning thanks to mlint
%
% - fplod 20101203T105554Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * time step in simulation #1 set to 30 days
%     (50 days give 8 steps which is confused with 8 digits of yyyymmdd)
%
% - fplod 20101202T142356Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add parameter information in header
%
% - fplod 20100923T141616Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation from simul_lai.m because impossible to define
%     lai_values(46,839041,839041) - too big
%     and better reproduction of longitude values
%-
%
result=-1;
%
usage='lon_value, lat_value, datejul_value, datestr_value, lai_value]=simul_lai_2d(index_simulaion)';
if nargin~=1
   disp(['Incorrect number of arguments']);
   error(usage);
end
%
arg_info=whos('index_simulation');
if ~strcmp(arg_info.class,'int8')
   disp(['Incorrect type of arg index_simulation']);
   whos index_simulation
   error(usage);
end
clear arg_info
%
% dfinition de la zone gographique : les coins en degr et les rsolutions
if (index_simulation == 1)
   % ici une boite [20E,10E] [10N,20N] et un point tous les 2 en latitude
   % et 5 en longitude
   lonmin_value=-20.;
   lonmax_value=-10.;
   latmin_value=10.;
   latmax_value=20.;
   lat_delta = 2.;
   lon_delta = 5.;
elseif (index_simulation == 2 )
   lonmin_value=-18.168;
   lonmax_value=-10.518;
   latmin_value=10.004;
   latmax_value=17.996;
   lat_delta = 0.0092930;
   lon_delta = 0.0087529;
else
   error(['eee : unknow simulation ' num2str(index_simulation)]);
end
%
% dfinition de la zone temporelle : l'anne et la rsolution
if (index_simulation == 1)
   % ici une valeur tous les 30 jours pour 2001
   yyyy_value=2001;
   datestr_delta=30;
elseif (index_simulation == 2 )
   % ici une valeur tous les 8 jours pour 2001
   yyyy_value=2001;
   datestr_delta=8;
else
   error(['eee : unknow simulation ' num2str(index_simulation)]);
end
clear index_simulation
% cration du tableau des longitudes
lon_basevalue=transpose(lonmin_value:lon_delta:lonmax_value);
clear lonmin_value
clear lonmax_value
clear lon_delta
%
% cration du tableau des latitudes
lat_basevalue=transpose(latmin_value:lat_delta:latmax_value);
clear latmin_value
clear latmax_value
clear lat_delta
%
nb_line=size(lat_basevalue,1)*size(lon_basevalue,1);
%
lon_orthovalue=repmat(lon_basevalue,size(lat_basevalue,1),1);
lon_value=zeros(nb_line,1);
lon_value(:)=NaN;
for index_line=1:nb_line
 offset=ceil(index_line/size(lon_basevalue,1))*0.5;
 lon_value(index_line)=lon_orthovalue(index_line)-offset;
end
clear offset
lat_value=zeros(nb_line,1);
lat_value(:)=NaN;
for index_line=1:nb_line
  index_lat=ceil(index_line/size(lon_basevalue,1));
  lat_value(index_line)=lat_basevalue(index_lat);
end
clear index_lat
clear lat_basevalue
clear lon_basevalue
clear lon_orthovalue
%
datejul_value=datenum(yyyy_value,1,1):datestr_delta:datenum(yyyy_value,12,eomday(yyyy_value,12));
clear yyyy_value
clear datestr_delta
%
% conversion datenum (unit octave/matlab) en format "yyyymmdd"
datestr_value=datestr(datejul_value,'yyyymmdd');
nb_datestr=size(datestr_value,1);
%
% cration de tableau LAI
lai_value=zeros(nb_line,nb_datestr);
lai_value(:,:)=NaN;
for index_line=1:nb_line
    for index_datestr=1:nb_datestr
       lai_value(index_line,index_datestr)=(index_datestr+index_line)/100.;
   end
end
clear nb_line
clear index_line
clear nb_datestr
clear index_datestr
%
%
result=0;
%
end

%!demo
%! % From scratch to create short array of LAI and associated arrays lat, long
%! % and datestr::
%! clear all
%! close all
%! varamma_startup
%! more off
%! index_simulation=int8(1);
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value]=simul_lai_2d(index_simulation);

%!demo
%! % From scratch to create long array of LAI and associated arrays lat, long
%! % and datestr::
%! clear all
%! close all
%! varamma_startup
%! more off
%! index_simulation=int8(2);
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value]=simul_lai_2d(index_simulation);
