function [spatialdimension1_fin, spatialdimension2_fin, mat_fin] = spatialresolution(spatialdimension1_ini, spatialdimension2_ini, mat_ini, newresoldim1, newresoldim2)

%SPATIALRESOLUTION est une fonction qui permet, par interpolation lineaire,
%de modifier la resolution spatiale 2D d'une matrice initiale de donnees
%(2D ou 3D avec une premiere dimension temporelle), ainsi que la resolution
%de ses coordonnees correspondantes.

%
%+
%
% ===================
% spatialresolution.m
% ===================
%
% .. function:: spatialresolution(spatialdimension1_ini, spatialdimension2_ini, mat_ini, newresoldim1, newresoldim2)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * mat_ini : Matrice initiale dont on souhaite modifier la resolution.
%   * spatialdimension1_ini : Coordonnees initiales pour la premiere
%     dimension spatiale (dim1) de la matrice de donnees.
%   * spatialdimension2_ini : Coordonnees initiales pour la seconde
%     dimension spatiale (dim2) de la matrice de donnees.
%   * newresoldim1 : Nouvelle resolution souhaitee pour la premiere
%     dimension spatiale.
%   * newresoldim2 : Nouvelle resolution souhaitee pour la seconde
%     dimension spatiale.
%
% - Donnees de sorties :
%
%   * mat_fin : Matrice finale issue de l'interpolation lineaire de la
%     matrice initiale mat_ini.
%   * spatialdimension1dim1_fin : Coordonnees finales pour la premiere
%     dimension spatiale (dim1) de la nouvelle matrice de donnees.
%   * spatialdimension2_fin : Coordonnees finales pour la seconde
%     dimension spatiale (dim2) de la nouvelle matrice de donnees.
%
% Cette fonction permet, par interpolation lineaire, de modifier la
% resolution spatiale d'une matrice initiale de donnees, ainsi que la
% resolution de ses coordonnees correspondantes.
% La matrice initiale peut-etre 2D (dim1, dim2) ou 3D si elle comporte, le
% temps en tant que premiere dimension de celle-ci (dimension temporelle,
% dim1, dim2). Dans ce dernier cas, l'interpolation se fait alors sur
% chaque pas de temps.
%
% EXAMPLES
% ========
%
% Voir la 'demo' avec visualisation de la matrice initiale et de la matrice
% finale issue de l'interpolation de la premiere.
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% Envisager une autre technique possible pour la grille d'interpolation
% pour eviter le "probleme des bords" qui se fait ressentir pour un fort
% changement de resolution (cf. demo, on a un changement dans les bornes
% des axes, axis nous donne :
%
% dans le cas initial::
%
%    -1.5000    1.5000   -4.5000    4.5000
%
% dans le cas final ::
%
%     -1.0714    1.0714   -4.2857    4.2857).
%
% Quelle methode est la plus pertinente ??
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110804T142141Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * octave and matlab 7.4 do not like [argout1,~, argout3]=myfunc() so
%     replace ~ by temporary variable
%
% - jaclod 2011-07-26
%
%   * Revision de la documentation et des commentaires.
%
% - jaclod 2011-07-11
%
%   * Modifications des variables pour plus de clarete.
%
% - jaclod 2011-07-07
%
%   * Creation.
%
%-

% Verification que les coordonnees de la premiere dimension spatiale est
% bien un vecteur (1D). Pour cela, on regarde si la matrice correspondant
% aux coordonnees est bien de deux dimensions dont l'une est unitee. Si
% l'une de ces conditions n'est pas satisfaite, on a un message d'erreur.
if size(size(spatialdimension1_ini),2) ~= 2 || isempty(find(size(spatialdimension1_ini)==1, 1)) == 1;

    error('Les coordonnees doivent etre sous forme de vecteur (une seule dimension).');

end

% De meme pour les coordonnees de la seconde dimension spatiale.
if size(size(spatialdimension2_ini),2) ~= 2 || isempty(find(size(spatialdimension2_ini)==1, 1)) == 1;

    error('Les coordonnees doivent etre sous forme de vecteur (une seule dimension).');

end

% Verification que la matrice initiale ne contient pas de NaN, ce qui
% fausserait l'interpolation.
if size(find(isnan(mat_ini)),1) ~= 0;

    error('La matrice initiale contient des NaN, l''interpolation ne peut etre juste.')

end

% Si les informations sur la nouvelle resolution n'ont pas ete donnees, on
% les demande a l'utilisateur.
if exist('newresoldim1','var')~=1;

    newresoldim1 = input('Nouvelle resolution pour la premiere dimension spatiale : ');

end

if exist('newresoldim2','var')~=1;

    newresoldim2 = input('Nouvelle resolution pour la seconde dimension spatiale : ');

end

% Recuperation de la resolution spatiale de la matrice initiale dans le cas
% 2D (dim1, dim2) ou 3D (dimension temporelle, dim1, dim2). Pour les autres
% cas (4D, 5D, ...), un message d'erreur apparait.
if size(size(mat_ini),2) == 2;

    [oldresoldim1,oldresoldim2] = size(mat_ini);

elseif size(size(mat_ini),2) == 3;

    [temp_dim,oldresoldim1,oldresoldim2] = size(mat_ini);
    clear temp_dim

else

    error('La matrice initiale doit avoir 2 dimensions spatiales (dim1, dim2) et eventuellement une premiere dimension temporelle (dim temp, dim1, dim2)');

end

% Ancienne grille.
x = 1:oldresoldim2;
y = 1:oldresoldim1;

% Creation de la nouvelle grille (On garde les memes intervalles mais pas
% le meme nombre d'elements dans chacun d'eux).
xi = linspace(1,oldresoldim2,newresoldim2);
yi = linspace(1,oldresoldim1,newresoldim1)';

% Interpolation 1D pour les coordonnees.
spatialdimension1_fin = interp1(y,spatialdimension1_ini,yi,'linear');
spatialdimension2_fin = interp1(x,spatialdimension2_ini,xi,'linear');

% Interpolation 2D pour la matrice de donnees. Une seule fois si la matrice
% initiale est 2D ou en bouclant sur la dimension temporelle dans le cas
% d'une matrice initiale 3D.
if size(size(mat_ini),2) == 2;

    mat_ini = double(mat_ini);
    mat_fin = interp2(x,y,mat_ini,xi,yi,'linear');

elseif size(size(mat_ini),2) == 3;

    mat_fin = zeros(size(mat_ini,1),newresoldim1,newresoldim2);

    % Boucle sur la variable temporelle :
    for timestep = 1:size(mat_ini,1);

        tmp_mat_ini = squeeze(double(mat_ini(timestep,:,:)));
        mat_fin(timestep,:,:) = interp2(x,y,tmp_mat_ini,xi,yi,'linear');

    end

end

end

%!demo
%! close all
%! clear all
%! varamma_startup
%! data_ini(:,1)=[3 4 5 6 7 6 5 4 3];
%! data_ini(:,2)=data_ini(:,1)-1;
%! data_ini(:,3)=data_ini(:,2)-1;
%! dim1lat_ini = -4:4;
%! dim2long_ini = -1:1;
%! newdim1latresol = 15;
%! newdim2longresol = 15;
%! [dim1lat_fin, dim2long_fin, data_fin] = spatialresolution(dim1lat_ini, dim2long_ini, data_ini, newdim1latresol, newdim2longresol);
%! subplot(1,2,1);
%! imagesc(dim2long_ini, dim1lat_ini, data_ini);
%! set(gca,'ydir','normal');
%! title('resolution initiale');
%! subplot(1,2,2);
%! imagesc(dim2long_fin, dim1lat_fin, data_fin);
%! set(gca,'ydir','normal');
%! title('resolution finale par interpolation');
