function [result]=write_lai_2d(lon_value, lat_value, datestr_value, lai_value)

%WRITE_LAI_2D write LAI file from LAI 2D array and associated arrays lat, lon, date

%
%+
%
% ==============
% write_lai_2d.m
% ==============
%
% .. function:: write_lai_2d(lon_value, lat_value, datestr_value, lai_value)
%
% DESCRIPTION
% ===========
%
%    :param lon_value: longitude array
%    :type lon_value: 1D array of floats
%    :raise lon_value: required
%
%    :param lat_value: latitude array
%    :type lat_value: 1D array of floats
%    :raise lat_value: required
%
%    :param datestr_value: date (yyyymmdd) array
%    :type datestr_value: 1D array of strings
%    :raise datestr_value: required
%
%    :param lai_value: LAI array
%    :type lai_value: 2D array of floats
%    :raise lai_value: required
%
%    :returns: 0 if ok or -1 if error
%    :rtype: integer
%
% Write in a file :file:`${PROJECT_OD}/LAI/laisen{yyyy}_write_lai_2d_float.txt` contents
% of 2D array of **lai_value**  for each date in **datestr_value**
% on each grid point defined by **lon_value** and **lat_value**.
%
% **datestr_value** are supposed to be in the same year.
%
% EXAMPLES
% ========
%
% From scratch to write some simulated LAI values in
% :file:`${PROJECT_OD}/LAI/laisen2001_write_lai_2d_float.txt`:
%
% see demo 1
%
% From real file :file:`${PROJECT_ID}/LAI/laisen2001_float.txt`:
%
% see demo 2
%
% SEE ALSO
% ========
%
% :ref:`guide data LAI <data_lai>`
%
% :func:`simul_lai`
% :func:`read_lai_2d`
% :func:`showgrid`
%
% TODO
% ====
%
% check arguments (type, size, value)
%
% clean
%
% EVOLUTIONS
% ==========
%
% $Id: write_lai_2d.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
% - fplod 20110302T091046Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * move examples to demo
%   * test inconsistent dimensions of arguments
%
% - fplod 20101208T103946Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * check arguments
%
% - fplod 20101206T152722Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * check arguments
%
% - fplod 20101206T103915Z adonis.locean-ipsl.upmc.fr (Linux)
%
%   * cleanning thanks to mlint
%
% - fplod 20101203T093624Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * dimension correction
%
% - fplod 20101202T142947Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * new terminology and new format
%   * add parameter information in header
%
% - fplod 20100826T120800Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation from write_lai.m because impossible to work
%     with lai_values(46,839041,839041) - too big
%
%-
%
global PROJECT_OD;
%
result=-1;
%
usage='result=write_lai_2d(lon_value, lat_value, datestr_value, lai_value)';
%
if nargin~=4
   disp(['Incorrect number of arguments']);
   error(usage);
end
%
arg_info=whos('lon_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg lon_value']);
   whos lon_value
   error(usage);
end
clear arg_info
%
arg_info=whos('lat_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg lat_value']);
   whos lat_value
   error(usage);
end
clear arg_info
%
if ~isvector(lon_value)
   disp(['Incorrect type of arg lon_value']);
   error(usage);
end
%
% ++ check arguments (type, size, values)
%
nb_lat=size(lat_value,1);
nb_lon=size(lon_value,1);
%
% check for sizes of parameters
if (not(isequal(nb_lat,nb_lon)))
   disp(['eee : inconsistent dimensions of lon_value, lat_value']);
    whos lat_value
    whos lon_value
    error(usage);
end
nb_datestr=size(datestr_value,1);
if (not(isequal(nb_datestr,size(lai_value,2))))
   disp(['eee : inconsistent dimension of datestr_value lai_value']);
    whos datestr_value
    whos lai_value
    error(usage);
end
if (not(isequal(nb_lat,size(lai_value,1))))
   disp(['eee : inconsistent dimension of lat_value lai_value']);
    whos lat_value
    whos lai_value
    error(usage);
end
%
clear nb_lon
nb_line=nb_lat;
%
% calculate doy
datenum_value=zeros(nb_datestr,1);
datenum_value(:)=NaN;
for index_datestr=1:nb_datestr
   datenum_value(index_datestr)=datenum(datestr_value(index_datestr,:),'yyyymmdd');
end
clear index_datestr
yyyy_floatvalue=str2double(datestr(datenum_value(1),'yyyy'));
doy_value=datenum_value(:) - datenum(yyyy_floatvalue,1,1) + 1;
clear datenum_value
%
% build LAI ASCII filename to be written
fullfilename=[PROJECT_OD 'LAI/laisen'  num2str(yyyy_floatvalue) '_' mfilename '_float.txt'];
clear yyyy_floatvalue
disp(['iii : opening for writing ', fullfilename]);
fid=fopen(fullfilename,'w');
clear fullfilename
%
% write header with days of year
format_header=['Y,X' repmat(',%3.3d',1,nb_datestr) '\n'];
fprintf(fid, format_header,doy_value(:)');
clear format_header
clear doy_value
%
% write data (lat, lon, lai)
format_data=['%6.3f,%7.3f' repmat(',%4.2f',1,nb_datestr) '\n'];
for index_line=1:nb_line
    fprintf(fid,format_data,lat_value(index_line),lon_value(index_line),lai_value(index_line,:));
end
clear nb_datestr
clear format_data
clear nb_line
clear index_line
fclose(fid);
clear fid
%
result=0;
%
end

%!demo
%! % From scratch to write some simulated LAI values in
%! % :file:`${PROJECT_OD}/LAI/laisen2001_write_lai_2d_float.txt`::
%! varamma_startup
%! more off
%! index_simulation=int8(1);
%! [lon_value, lat_value, datestr_value, lai_value]=simul_lai_2d(index_simulation);
%! result=write_lai_2d(lon_value, lat_value, datestr_value, lai_value);

%!demo
%! % From real file :file:`${PROJECT_ID}/LAI/laisen2001_float.txt`::
%! varamma_startup
%! more off
%! yyyy=int16(2001);
%! [lon_value, lat_value, datestr_value, lai_value]=read_lai_2d(yyyy);
%! result=write_lai_2d(lon_value, lat_value, datestr_value, lai_value);
