function [result]=write_precip(station, datestr_value, precip_value, datasettype)

%WRITE_PRECIP write precipitation file :file:`${PROJECT_OD}/PRECIP/{station}_pluie_{yyyy}.csv`
%or file :file:`${PROJECT_OD}/PRECIP/pluvio_{station}_{yyyy}.csv`
%from precipitation 2D array and associated array datestr

%
%+
%
% ==============
% write_precip.m
% ==============
%
% .. function:: write_precip(station, datestr_value, precip_value, datasettype)
%
% DESCRIPTION
% ===========
%
%    :param station: station
%    :type station: string
%    :raise station: required
%
%    :param datestr_value: date (yyyymmdd) array
%    :type datestr_value: 1D array of strings
%    :raise datestr_value: required
%
%    :param precip_value: precipitation array
%    :type precip_value: 2D array of floats
%    :raise precip_value: required
%
%    :param station: datasettype precip_cm or precip_cd
%    :type station: string
%    :raise station: required
%
%    :returns: 0 if ok or -1 if error
%    :rtype: integer
%
% Write in a file :file:`${PROJECT_OD}/PRECIP/{station}_pluie_{yyyy}_write_precip.csv`
% if datasettype is set to ``precip_cm`` (like column month) or
% file :file:`${PROJECT_OD}/PRECIP/pluvio_{station}_{yyyy}.csv`
% if datasettype is set to ``precip_cd`` (like column day)
% contents of 2D array of **precip_value**  for each date in **datestr_value**
%
% **datestr_value** are supposed to be in the same year.
%
% EXAMPLES
% ========
%
% From scratch to write some simulated precipitation values in
% :file:`${PROJECT_OD}/PRECIP/barkedji_pluie_2006_write_precip.csv`:
%
% see demo 1
%
% From real file :file:`${PROJECT_ID}/PRECIP/barkedji_pluie_2006.csv`:
%
% see demo 2
%
% From scratch to write some simulated precipitation values in
% :file:`${PROJECT_OD}/PRECIP/pluvio_linguere_2006_write_precip.csv`:
%
% see demo 3
%
% From real file :file:`${PROJECT_ID}/PRECIP/pluvio_linguere_2006.csv`:
%
% see demo 4
%
% SEE ALSO
% ========
%
% :ref:`guide data precipitation <data_precipitation_insitu>`
%
% :func:`simul_precip`
% :func:`read_precip`
%
% TODO
% ====
%
% check arguments (type, size, value)
%
% clean
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL$
%
% - fplod 20110302T092454Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * test inconsistent dimensions of arguments
%
% - fplod 20110228T143925Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * examples moved to demo
%   * fix nargin value
%
% - fplod 20110221T154746Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * remove usage of geolocation
%
% - fplod 20110124T122820Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * introducing parameter datasettype precip_cm or precip_cd
%   * add reading :file:`pluvio_{station}_{yyyy}.csv`
%
% - fplod 20110114T161738Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * work in progress
%
% - fplod 20110112T112252Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation
%
%-
%
global PROJECT_OD;
%
result=-1;
%
usage='result=write_precip(station, datestr_value, precip_value, datasettype)';
%
if nargin~=4
   disp(['Incorrect number of arguments ' num2str(nargin)]);
   error(usage);
end
%
arg_info=whos('station');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg station ' arg_info.class]);
   whos station
   error(usage);
end
clear arg_info
%
arg_info=whos('datasettype');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg datasettype ' arg_info.class]);
   whos station
   error(usage);
end
clear arg_info
%
% ++ check arguments (type, size, values)
%
% preallocation of month_value array to missing value 999
months_in_year_max=12;
month_value=repmat(99,months_in_year_max);
clear months_in_year_max
%
nb_datestr=size(datestr_value,1);
if (not(isequal(nb_datestr,size(precip_value,2))))
   disp(['eee : inconsistent dimensions of datestr_value precip_value']);
   whos datestr_value
   whos precip_value
   error(usage);
end
%
% calculate minimal/max month and year
datenum_value=zeros(nb_datestr,1,'double');
datenum_value(:)=NaN;
for index_datestr=1:nb_datestr
   datenum_value(index_datestr)=datenum(datestr_value(index_datestr,:),'yyyymmdd');
end
datenum_min=min(datenum_value);
mm_min=str2double(datestr(datenum_min,'mm'));
yyyy_min=datestr(datenum_min,'yyyy');
datenum_max=max(datenum_value);
mm_max=str2double(datestr(datenum_max,'mm'));
yyyy_max=datestr(datenum_max,'yyyy');
%
% check only one year
if ~strcmp(yyyy_min,yyyy_max)
   disp([' yyyy_min = ' yyyy_min ' yyyy_max = ' yyyy_max]);
   error('eee : yyyy_min and yyyy_max different')
end
dyyyy=str2double(yyyy_min);
nb_month=mm_max - mm_min + 1;
%
clear index_datestr
index_month_value=1;
for imonth=mm_min:mm_max
    month_value(index_month_value)=str2double(datestr(datenum(dyyyy,imonth,1),'mm'));
    index_month_value=index_month_value+1;
end
clear imonth
clear index_month_value
%
% build precipitation ASCII filename to be written
switch datasettype
   case {'precip_cm'}
      fullfilename=[PROJECT_OD '/PRECIP/'  station '_pluie_' yyyy_min '_' mfilename '.csv'];
   case {'precip_cd'}
      fullfilename=[PROJECT_OD '/PRECIP/' 'pluvio_' station '_' yyyy_min '_' mfilename '.csv'];
   otherwise
      error(['eee : unknown datasettype ' datasettype])
end
disp(['iii : opening for writing ', fullfilename]);
fid=fopen(fullfilename,'w');
clear fullfilename
%
% +todo+ check opening ok
%
% the maximum of day is the number of days in a month
days_in_month_max = 31;
% the maximum of month is the number of months in a year
months_in_year_max = 12;
% the maximum of geolocation is 1 in this type of file
nb_geolocation_max = 1;
index_geolocation=1;
switch datasettype
   case {'precip_cm'}
      % preallocation of precip_rd_cm array to missing value NaN
      % note : precip_rd_cm for precip array arrange with column = month and row = day
      precip_rd_cm=repmat(-99.9,days_in_month_max,nb_month);
      %
      % fill precip_rd_cm value
      % loop on date
      for index_date=1:nb_datestr
          index_row = str2double(datestr_value(index_date,7:8));
          index_column = str2double(datestr_value(index_date,5:6)) - mm_min + 1;
          %debug disp([ datestr_value(index_date,:) ' ' num2str(index_row) ' ' num2str(index_column) ' ' num2str(precip_value(index_geolocation,index_date)) ]);
          precip_rd_cm(index_row,index_column)=precip_value(index_geolocation,index_date);
      end
      %
      % write header with month names
      format_header=['"Days"' repmat(',%2.2d',1,nb_month) '\n'];
      fprintf(fid, format_header,month_value(1:nb_month)');
      clear format_header
      clear month_value
      %
      % write data (day precip)
      format_data=['%2.2d' repmat(',%5.1f',1,nb_month) '\n'];
      % loop on row
      nb_row=31;
      for index_row=1:nb_row
          fprintf(fid,format_data,index_row,precip_rd_cm(index_row,:));
      end
      clear nb_month
      clear format_data
      clear nb_row
      clear index_row
   case {'precip_cd'}
      % preallocation of precip_rm_cd array to missing value NaN
      % note : precip_rm_cd for precip array arrange with column = month and row = day
      precip_rm_cd=repmat(-99.9,nb_month,days_in_month_max);
      % fill precip_rm_cd value
      % loop on date
      for index_date=1:nb_datestr
          index_column = str2double(datestr_value(index_date,7:8));
          index_row = str2double(datestr_value(index_date,5:6)) - mm_min + 1;
          % debug disp([ datestr_value(index_date,:) ' ' num2str(index_row) ' ' num2str(index_column) ' ' num2str(precip_value(index_geolocation,index_date)) ]);
          precip_rm_cd(index_row,index_column)=precip_value(index_geolocation,index_date);
      end
      %
      % write data (day precip)
      format_data=['%s,%s' repmat(',%5.1f',1,days_in_month_max) '\n'];
      cyyyy=num2str(yyyy_min,'%4.4d');
      % loop on row
      nb_row=nb_month;
      for index_row=1:nb_row
          cmonth=num2str(month_value(index_row),'%2.2d');
          fprintf(fid,format_data,cyyyy,cmonth,precip_rm_cd(index_row,:));
          clear cmonth
      end
      clear cyyyy
   otherwise
      error(['eee : unknown datasettype ' datasettype])
end
%
fclose(fid);
clear fid
%
clear usage
%
%++whos;
result=0;
%
end

%!demo
%! % From scratch to write some simulated precipitation values in
%! % :file:`${PROJECT_OD}/PRECIP/barkedji_pluie_2006_write_precip.csv`::
%! varamma_startup
%! more off
%! station='barkedji';
%! index_simulation=int8(1);
%! [datestr_value, precip_value]=simul_precip(station, index_simulation);
%! datasettype='precip_cm';
%! result=write_precip(station, datestr_value, precip_value, datasettype);

%!demo
%! % From real file :file:`${PROJECT_ID}/PRECIP/barkedji_pluie_2006.csv`::
%! varamma_startup
%! more off
%! yyyy=int16(2006);
%! station='barkedji';
%! datasettype='precip_cm';
%! [datestr_value, precip_value]=read_precip(station, yyyy, datasettype);
%! result=write_precip(station, datestr_value, precip_value, datasettype);

%!demo
%! % From scratch to write some simulated precipitation values in
%! % :file:`${PROJECT_OD}/PRECIP/pluvio_linguere_2006_write_precip.csv`::
%! varamma_startup
%! more off
%! station='linguere';
%! index_simulation=int8(1);
%! [datestr_value, precip_value]=simul_precip(station, index_simulation);
%! datasettype='precip_cd';
%! result=write_precip(station, datestr_value, precip_value, datasettype);

%!demo
%! % From real file :file:`${PROJECT_ID}/PRECIP/pluvio_linguere_2006.csv`::
%! varamma_startup
%! more off
%! yyyy=int16(2006);
%! station='linguere';
%! datasettype='precip_cd';
%! [datestr_value, precip_value]=read_precip(station, yyyy, datasettype);
%! result=write_precip(station, datestr_value, precip_value, datasettype);
